## Watch Server

Used by Mountaineer CLI hooks to isolate your server and push updates to live-reload browsers. You probably won't have to deal with this class explicitly.

::: mountaineer.watch.PackageWatchdog

::: mountaineer.watch_server.WatcherWebservice

::: mountaineer.cli.IsolatedEnvProcess
